@@ -3,7 +3,7 @@
 namespace Mockery;
 
 use Mockery as m;
-use Mockery\Fixtures\SemiReservedWordsAsMethods;
+use test\Mockery\Fixtures\SemiReservedWordsAsMethods;
 use PHPUnit\Framework\TestCase;
 
 class MockeryCanMockClassesWithSemiReservedWordsTest extends TestCase
@@ -13,9 +13,7 @@ class MockeryCanMockClassesWithSemiReservedWordsTest extends TestCase
      */
     public function smoke_test()
     {
-        require __DIR__ . '/Fixtures/SemiReservedWordsAsMethods.php';
-
-        $mock = m::mock("Mockery\Fixtures\SemiReservedWordsAsMethods");
+        $mock = m::mock(SemiReservedWordsAsMethods::class);
 
         $mock->shouldReceive("include")->andReturn("foo");
 
