@@ -2,7 +2,7 @@
 
 declare(strict_types=1);
 
-namespace test\Unit\PHP81;
+namespace Tests\Unit\PHP81;
 
 use Fixture\PHP81\HandlerClass;
 use Fixture\PHP81\MockClass;
@@ -10,8 +10,9 @@ use Mockery\Adapter\Phpunit\MockeryTestCase;
 
 /**
  * @requires PHP 8.1.0-dev
+ * @coversDefaultClass \Mockery
  */
-class Php81LanguageFeaturesTest extends MockeryTestCase
+final class Php81LanguageFeaturesTest extends MockeryTestCase
 {
     public function testNewInitializerExpression()
     {
